#!/usr/bin/python3

import os
from pathlib import Path
import hashlib
import json


def calculate_sha256sum(file_path):
    """Calculate the SHA-256 checksum of a file."""
    sha256 = hashlib.sha256()
    with open(file_path, "rb") as f:
        while chunk := f.read(8192):
            sha256.update(chunk)
    return sha256.hexdigest()


def generate_checksums(root_dir):
    """Generate a dictionary of file paths and their SHA-256 checksums."""
    checksums = {}
    for dirpath, dirnames, filenames in os.walk(root_dir):
        for filename in filenames:
            file_path = os.path.join(dirpath, filename)
            relative_path = os.path.relpath(file_path, root_dir)
            checksums[relative_path] = calculate_sha256sum(file_path)
    return checksums


def main():
    # The cargo-checksum.json is required only for the library
    root_dir = "hwlib"
    checksums = generate_checksums(root_dir)

    cargo_checksum = {"files": checksums}

    with open(Path(Path(__file__).parent, "cargo-checksum.json"), "w") as f:
        json.dump(cargo_checksum, f, separators=(",", ":"))

    print("debian/cargo-checksum.json has been generated.")


if __name__ == "__main__":
    main()



#!/usr/bin/env python3

import socketserver
import sys
from http.server import BaseHTTPRequestHandler
from json import dumps
import socket
import os

RESPONSE = dumps({"status": "Not Seen"}).encode()

class CustomHandler(BaseHTTPRequestHandler):
    def do_POST(self):
        if self.path == "/v1/certification/status":
            self.send_response(200)
            self.send_header("Content-Type", "application/json")
            self.send_header("Content-Length", str(len(RESPONSE)))
            self.end_headers()
            self.wfile.write(RESPONSE)
        else:
            self.send_response(404)
            self.end_headers()

def notify_systemd_ready():
    """Notify systemd that the service is ready"""
    notify_socket = os.getenv("NOTIFY_SOCKET")
    if notify_socket:
        sock = socket.socket(socket.AF_UNIX, socket.SOCK_DGRAM)
        try:
            sock.connect(notify_socket)
            sock.sendall(b"READY=1\n")
        finally:
            sock.close()
        print("Systemd notified: READY=1", file=sys.stderr)

PORT = 8089
with socketserver.TCPServer(("", PORT), CustomHandler) as httpd:
    print(f"Starting mock server on port {PORT}", file=sys.stderr)
    # Notify systemd of readiness
    notify_systemd_ready()
    httpd.serve_forever()
